==> mongodb-src-r3.0.14.tar.gz: mongodb-src-r3.0.14/src/mongo/s/shard_resolver.h <==
/**
 *    Copyright (C) 2013 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>

#include "mongo/base/status.h"
#include "mongo/client/dbclientinterface.h"
#include "mongo/s/shard_resolver.h"

namespace mongo {

/**
 * Given a shard name, the ShardResolver resolves a particular host on that shard to contact.
 *
 * TODO: Internally, this is backed by a cache - do we need explicit refresh mechanisms built
 * into this interface?
 */
class ShardResolver {
public:
    virtual ~ShardResolver() {}

    /**
     * Returns a host we can use for write ops to this shard.
     *
     * Returns !OK with message if the shard host could not be found for other reasons.
     */
    virtual Status chooseWriteHost(const std::string& shardName,
                                   ConnectionString* shardHost) const = 0;
};

}  // namespace mongo

==> mongodb-src-r3.2.17.tar.gz: mongodb-src-r3.2.17/src/mongo/s/shard_resolver.h <==
/**
 *    Copyright (C) 2013 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>

#include "mongo/base/status.h"
#include "mongo/client/dbclientinterface.h"
#include "mongo/s/shard_resolver.h"

namespace mongo {

class OperationContext;

/**
 * Given a shard name, the ShardResolver resolves a particular host on that shard to contact.
 *
 * TODO: Internally, this is backed by a cache - do we need explicit refresh mechanisms built
 * into this interface?
 */
class ShardResolver {
public:
    virtual ~ShardResolver() {}

    /**
     * Returns a host we can use for write ops to this shard.
     *
     * Returns !OK with message if the shard host could not be found for other reasons.
     */
    virtual Status chooseWriteHost(OperationContext* txn,
                                   const std::string& shardName,
                                   ConnectionString* shardHost) const = 0;
};

}  // namespace mongo
